from PyQt4.QtGui import QMainWindow, QGraphicsView
from PyQt4.QtCore import pyqtSignature, Qt, SIGNAL, QPoint




class styloKeys(QGraphicsView):
    """
    Class documentation goes here.
    """
    keyid=[1, 13, 13, 2, 3, 14, 14,15, 15,5, 6, 16, 16, 17, 17, 18, 18, 9, 10, 19, 19, 20, 20, 12, 0 ]
    lastbutton=0
    keyrelease=0
    def __init__(self, parent):
        QGraphicsView.__init__(self, parent)
        # some custom properties and functions will follow
        
    def mousePressEvent(self, event):    
        self.mouseMoveEvent(event)
        event.accept()
        
    def mouseReleaseEvent(self, event):
        self.emit(SIGNAL("stylo released"))
        event.accept()
        self.keyrelease=1
    
    def mouseMoveEvent(self, event):
        self.mousePressPos = QPoint(event.pos())
        self.x = self.mousePressPos.x()
        self.y = self.mousePressPos.y()
         #print "Mouse moved ", self.x,self.y
        #check to see if we aare inside the qgraphicsview,then see if we are in bottom or top half of keyboard
        if self.x<=635 and self.x>=0:
            if self.y>=50:self.buttonid=int(self.x/53)+1
            #otherwise need to find small button. upper keyboard divided into 24 keys
            else:
                tempbuttonid=int(self.x/26.5)
                self.buttonid=self.keyid[tempbuttonid]
             #has a key been pressed   
            if self.keyrelease==1:
               self.emit(SIGNAL("stylo changed"),self.buttonid)        
               self.keyrelease=0
               #print "pressed", self.buttonid
            elif self.buttonid!=self.lastbutton:self.emit(SIGNAL("stylo changed"), self.buttonid)
               #print "moved", self.buttonid
            
            self.lastbutton=self.buttonid
        #print "keypressed", self.buttonid, self.x, self.y
        event.accept()
      
    




